@@ -39,7 +39,7 @@
 class PinDialog : public KDialogBase
 {
 
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     PinDialog(const TQString &addr, const TQString &devName);
